==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/template/barnraiser_01/index.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?
			include($templatePath . 'p_menu.inc.php');
			?>
		</td>

    	<td width="20">
			<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" /><br />
		</td>

		<td width="360" valign="top">
			<div class="box_top">
				<?php echo $lang['section_intro'];?><br />
			</div>

			<div class="box_mid" style="padding: 9px;">
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
		  			<td>
						<?php echo $lang['txt_intro'];?>
					</td>
		  		</tr>
		  	</table>
			<?php
			if (isset($blogs)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td>
						<b><?php echo $lang['section_blogs'];?></b><br />
					</td>
				</tr>
				<?php
				foreach($blogs as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="p_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['blog_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>

			<?php
			if (isset($polls)) {
 			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

 			<table border="0" cellspacing="4" cellpadding="0" width="100%">
 				<tr>
 					<td>
 						<b><?php echo $lang['section_polls'];?></b><br />
 					</td>
 				</tr>
 				<?php
 				foreach($polls as $key => $i):
 				?>
 				<tr>
 					<td valign="top">
 						<?php
						$poll = $i;
 						include $templatePath . "poll.inc.tpl.php";
 						?>
 					</td>
 			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
 				<?php
 				endforeach;
 				?>
 			</table>
			<?php }?>

			<?php
			if (isset($library_items)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td>
						<b><?php echo $lang['section_library_items'];?></b><br />
					</td>
				</tr>
				<?php
				foreach($library_items as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="p_item.php?library_id=<?php echo $i['library_id'];?>"><?php echo $i['library_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['library_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>
			</div>

			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>


		</td>

		<td width="20">
			<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" /><br />
		</td>

		<td valign="top" width="180">
			<div class="box_top">
				<?php echo $lang['section_login'];?><br />
			</div>

			<div class="box_mid" style="padding: 9px;">
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td>
						<form action="index.php" method="post">
						<input type="hidden" name="http_referer" value="<?php if (isset($http_referer)) { echo $http_referer;}?>" />
						<label for="id_email"><?php echo $lang['txt_email'];?></label><br />
					</td>
				</tr>
				<tr>
					<td>
						<input id="id_email" type="text" name="email" size="20" value="" /><br />
					</td>
				</tr>
				<tr>
					<td>
						<label for="id_password"><?php echo $lang['txt_password'];?></label><br />
					</td>
				</tr>
				<tr>
					<td>
						<input id="id_password" type="password" name="password" size="12" value="" /><br />
					</td>
				</tr>
				<tr>
					<td align="right">
						<input type="submit" name="login" value="enter" class="button_urgent" /><br />
						</form>
					</td>
				</tr>
			</table>
			</div>

			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />

			<div class="box_top">
				<?php echo $lang['section_password'];?><br />
			</div>

			<div class="box_mid" style="padding: 9px;">
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td>
						<?php echo $lang['txt_new_password'];?>
					</td>
				</tr>
			</table>
			</div>

			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>

==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/template/barnraiser_01/index.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>

<table width="760" border="0" cellspacing="0" cellpadding="0">
	<tr>
		<td width="180" valign="top">
			<?
			include($templatePath . 'p_menu.inc.php');
			?>
		</td>

    	<td width="20">
			<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" /><br />
		</td>

		<td width="360" valign="top">
			<div class="box_top">
				<?php echo $lang['section_intro'];?><br />
			</div>

			<div class="box_mid" style="padding: 9px;">
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
		  			<td>
						<?php echo $lang['txt_intro'];?>
					</td>
		  		</tr>
		  	</table>
			<?php
			if (isset($blogs)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td>
						<b><?php echo $lang['section_blogs'];?></b><br />
					</td>
				</tr>
				<?php
				foreach($blogs as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="p_item.php?blog_id=<?php echo $i['blog_id'];?>"><?php echo $i['blog_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['blog_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>

			<?php
			if (isset($polls)) {
 			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

 			<table border="0" cellspacing="4" cellpadding="0" width="100%">
 				<tr>
 					<td>
 						<b><?php echo $lang['section_polls'];?></b><br />
 					</td>
 				</tr>
 				<?php
 				foreach($polls as $key => $i):
 				?>
 				<tr>
 					<td valign="top">
 						<?php
						$poll = $i;
						$poll_url = "p_item.php?poll_id=" . $i['poll_id'];
 						include $templatePath . "poll.inc.tpl.php";
 						?>
 					</td>
 			    </tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
 				<?php
 				endforeach;
 				?>
 			</table>
			<?php }?>

			<?php
			if (isset($library_items)) {
			?>
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />

			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td>
						<b><?php echo $lang['section_library_items'];?></b><br />
					</td>
				</tr>
				<?php
				foreach($library_items as $key => $i):
				?>
				<tr>
					<td>
						<table width="100%" cellpadding="2" cellspacing="0" border="0">
							<tr>
								<td width="3" valign="top" rowspan="2">
									<img src="<?php echo $templatePath;?>img/green_dot.png" width="3" height="9" alt="" /><br />
								</td>
								<td>
									<a href="p_item.php?page=<?php echo $i['library_page_name'];?>"><?php echo $i['library_create_datetime'];?></a><br />
								</td>
							</tr>
							<tr>
								<td>
									<?php echo $i['library_title'];?><br />
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<tr>
					<td>
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="2" alt="" /><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			
			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="10" alt="" /><br />
			<?php }?>
			
			<?php
			if (isset($subjects)) {
			?>
			<table width="100%" cellpadding="4" cellspacing="0" border="0">
				<tr>
					<td>
						<b><?php echo $lang['section_subjects'];?></b><br />
					</td>
				</tr>
				<?php
				foreach($subjects as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="p_item.php?subject_id=<?php echo $i['subject_id'];?>"><?php echo $i['subject_create_datetime'];?></a><br />
						<?php echo $i['subject_title'];?><br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
			</table>
			<?php }?>
			</div>

			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>


		</td>

		<td width="20">
			<img src="<?php echo $templatePath;?>img/pixel.png" width="20" height="1" alt="" /><br />
		</td>

		<td valign="top" width="180">
			<div class="box_top">
				<?php echo $lang['section_login'];?><br />
			</div>

			<div class="box_mid" style="padding: 9px;">
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td>
						<form action="index.php" method="post">
						<input type="hidden" name="http_referer" value="<?php if (isset($http_referer)) { echo $http_referer;}?>" />
						<label for="id_email"><?php echo $lang['txt_email'];?></label><br />
					</td>
				</tr>
				<tr>
					<td>
						<input id="id_email" type="text" name="email" size="20" value="" /><br />
					</td>
				</tr>
				<tr>
					<td>
						<label for="id_password"><?php echo $lang['txt_password'];?></label><br />
					</td>
				</tr>
				<tr>
					<td>
						<input id="id_password" type="password" name="password" size="12" value="" /><br />
					</td>
				</tr>
				<tr>
					<td align="right">
						<input type="submit" name="login" value="enter" class="button_urgent" /><br />
						</form>
					</td>
				</tr>
			</table>
			</div>

			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>

			<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="6" alt="" /><br />

			<div class="box_top">
				<?php echo $lang['section_password'];?><br />
			</div>

			<div class="box_mid" style="padding: 9px;">
			<table cellpadding="4" cellspacing="0" border="0" width="100%">
				<tr>
					<td>
						<?php echo $lang['txt_new_password'];?>
					</td>
				</tr>
			</table>
			</div>

			<div id="box_bottom">
				<table cellpadding="0" cellspacing="0" border="0" width="100%">
					<tr>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
						</td>
						<td align="left">
							<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
						</td>
						<td align="right">
							<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
						</td>
					</tr>
				</table>
			</div>
		</td>
	</tr>
</table>
